# RyGames

Python games by Ryan J Slater<br>
[GitHub](https://github.com/rjslater2000/RyGames)

To install:<br>
`pip install rygames`

## Games

* CoinGame
* CountryGuessingGame
* Hangman
* TicTacToe1Player
* TicTacToe2Player
* TwentyFortyEight
* Warships

Run any of them by importing `rygames`, then calling, for example:

```
>>import rygames as rg
>>rg.Warships()
```

## Requirements

* pygame >= 1.9.3
* numpy >= 1.13.3
* matplotlib >= 2.1.0
* PyDictionary >= 1.5.1
* nltk >= 3.2.4
* names >= 0.3.0
